@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.83'; # VERSION
+our $VERSION = '1.84'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -108,12 +108,9 @@ sub configure
   
   $self->add_plugins([ NextRelease => { format => '%-9v %{yyyy-MM-dd HH:mm:ss Z}d' }]);
     
-  $self->add_plugins(qw(
-    AutoPrereqs
-    OurPkgVersion
-    MetaJSON
-
-  ));
+  $self->add_plugins('AutoPrereqs');
+  $self->add_plugins($self->payload->{version_plugin} || 'OurPkgVersion');
+  $self->add_plugins('MetaJSON');
 
   if($] >= 5.010001 && $^O ne 'MSWin32')
   {
@@ -260,7 +257,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.83
+version 1.84
 
 =head1 SYNOPSIS
 
@@ -460,6 +457,10 @@ Additional dirty allowed file passed to @Git.
 IRC discussion URL for x_IRC meta (maybe changed to non x_ meta if/when IRC
 becomes formally supported).
 
+=head2 version_plugin
+
+Specify an alternative to OurPkgVersion for updating the versions in .pm files.
+
 =head1 SEE ALSO
 
 =over 4
